@@ -333,7 +333,8 @@ def show(username, tables):
                     query = query & {"experimenter": username}
 
                 # for sequential filters, check experimenter is the user
-                if st.session_state["search_mode"] == "Sequential Filter" and (
+                admin = (tables["Experimenter"] & {"experimenter": username}).fetch1("admin")
+                if admin == "False" and st.session_state["search_mode"] == "Sequential Filter" and (
                     "experimenter" not in restriction.keys()
                     or not restriction["experimenter"] == username
                 ):
@@ -461,7 +462,7 @@ def show(username, tables):
 
                                 elif delete_mode == "perm":
                                     # delete data
-                                    delete_query.delete_quick()
+                                    delete_query.delete(safemode=False, force=True)
 
                                     st.success("Data deleted.")
 
