@@ -377,6 +377,13 @@ def check_session(tables, insert_dict):
     return all(checkls)
 
 
+def get_ephys_extensions():
+    resources = Path(os.path.abspath(__file__)).parent.parent / "resources"
+    with open(resources / "ephys_extensions.json") as f:
+        extensions = json.load(f)
+    return extensions
+
+
 def upload(
     tablename, insert_dict, mode="insert", conn=None, username=None, password=None
 ):
@@ -401,16 +408,18 @@ def upload(
         dirpath = insert_dict["recording"]
 
         # create zipfile name from primary key
+        """
+        # old filepath
         filename = (
             "-".join([str(list(insert_dict.values())[i]) for i in range(4)]) + ".zip"
         )
         recfile = Path(tempfile.gettempdir()) / "antelop_raw" / Path(filename)
         recfile.parent.mkdir(parents=True, exist_ok=True)
+        """
+        recfile = Path(dirpath).with_suffix(".zip")
 
         # get files to zip
-        resources = Path(os.path.abspath(__file__)).parent.parent / "resources"
-        with open(resources / "ephys_extensions.json") as f:
-            extensions = json.load(f)
+        extensions = get_ephys_extensions()
         ephys_acquisition = insert_dict["ephys_acquisition"]
         equip_ext = extensions[ephys_acquisition]
         files = []
