@@ -17,6 +17,7 @@ from antelop.utils.datajoint_utils import (
     insertable_tables,
     delete_restriction,
     get_tablename,
+    get_ephys_extensions,
 )
 from antelop.utils.os_utils import get_config
 from antelop.connection import import_schemas
@@ -668,6 +669,11 @@ def dropdown_insert_table(
             timestamp = datetime.combine(date, time)
             insert_dict[key] = timestamp
 
+        # if it's ephys_acquisition, select from dropdown of options
+        elif key == "ephys_acquisition":
+            extensions = list(get_ephys_extensions().keys())
+            insert_dict[key] = st.selectbox("Select " + key, extensions)
+
         elif key in ["yaw", "pitch", "roll"]:
             insert_dict[key] = st.slider("Enter " + key + " (deg)", -180, 180, 0, 1)
 
@@ -716,7 +722,7 @@ def dropdown_insert_table(
     return tablename, insert_dict
 
 
-def server_directory_browser(message, extension="directory"):
+def server_directory_browser(message, extension="directory", custom_path=None):
     """
     A custom Streamlit widget that allows the user to browse directories on the server side.
 
@@ -724,9 +730,12 @@ def server_directory_browser(message, extension="directory"):
     """
 
     # default root directory should be mounted into the container
-    config = get_config()
-    basedir = st.selectbox(message, config["folders"].keys(), key=message)
-    current_directory = Path(config["folders"][basedir])
+    if custom_path:
+        current_directory = Path(custom_path)
+    else:
+        config = get_config()
+        basedir = st.selectbox(message, config["folders"].keys(), key=message)
+        current_directory = Path(config["folders"][basedir])
 
     if extension == "directory":
         counter = 0
@@ -1541,3 +1550,18 @@ def select_analysis(analysis_functions):
         else:
             analysis_functions = analysis_functions[function]
     return analysis_functions
+
+
+def select_probe():
+    """
+    Function gets user to select probe from resources
+    """
+
+    resources = (
+        Path(os.path.abspath(__file__)).parent.parent / "resources"
+    )
+    probedir = resources / "probes"
+    selected_probe = server_directory_browser('Select probe', extension='directory', custom_path=probedir)
+    if len(list(selected_probe.glob("*.json"))) > 0:
+        selected_probe = list(selected_probe.glob("*.json"))[0]
+        return selected_probe
\ No newline at end of file
