@@ -10,6 +10,8 @@ import pandas as pd
 import matplotlib.pyplot as plt
 import probeinterface as pi
 from probeinterface.plotting import plot_probe_group
+from pathlib import Path
+import os
 
 
 @st.cache_data(ttl=3600)
@@ -1143,9 +1145,16 @@ def unit_stats(spikesorting_dict, selected_units):
 
 
 def plot_probe(probefile):
+
+    # check if probefile in resources
+    resources = Path(os.path.abspath(__file__)).parent.parent / "resources"
+    for path in resources.rglob(Path(probefile).with_suffix(".png").name):
+        if path.is_file():
+            return path
+    
+    # otherwise plot manually
     probe = pi.io.read_probeinterface(probefile)
     fig = plt.figure()
     ax = fig.add_subplot(1, 1, 1, projection="3d")
     plot_probe_group(probe, ax=ax)
-
     return fig
